#!/usr/bin/python
# -*- encoding: utf-8; py-indent-offset: 4 -*-
#
# License: GNU General Public License v2
#
# Author: thl-cmk[at]outlook[dot]com
# URL   : https://thl-cmk.hopto.org
# Date  : 2020-06-22
#
# Huawei BGP Peer
#
#


huawei_bgp_peers_infotext_values = [
    ('remoteas', 'Remote autonomous system'),
    ('negotiatedversion', 'Negotiated version'),
    ('lasterror', 'Last error')
]


register_check_parameters(
    subgroup_networking,
    'huawei_bgp_peers',
    _('Huawei BGP peer'),
    Dictionary(
        help=_(''),
        elements=[
            ('minuptime',
             Integer(
                 help=_('Set the time in seconds, a peer must be up before the peer is considered sable.'
                        'If the peer uptime less then X, the check outcome is set to warning.'),
                 title=_('Minimum uptime for peer. If uptime less, set check outcome to warning. Default is 1 day.'),
                 default_value=86400,
                 allow_empty=False,
                 unit='seconds',
                 minvalue=1,
             ),
             ),
            ('infotext_values',
             ListChoice(
                 title=_('Remove values from Infotext'),
                 label=_('Remove values from infotext'),
                 help=_('Select values to remove from check output.'),
                 choices=huawei_bgp_peers_infotext_values,
                 default_value=[],
             )),
            ('peer_list',
             ListOf(
                 Tuple(
                     title=('BGP Peers'),
                     elements=[
                         TextUnicode(
                             title=_('BGP Peer item name (without "Huawei BGP peer")'),
                             help=_('The configured value must match a BGP item reported by the monitored '
                                    'device. For example: "10.194.115.98 IPv4 Unicast"'),
                             allow_empty=False,
                         ),
                         TextUnicode(
                             title=_('BGP Peer Alias'),
                             help=_('You can configure an individual alias here for the BGP peer matching '
                                    'the text configured in the "BGP Peer item name" field. The alias will '
                                    'be shown in the infotext'),
                         ),
                         MonitoringState(
                             default_value=2,
                             title=_('State if not found'),
                             help=_('You can configure an individual state if the BGP peer matching the text '
                                     'configured in the "BGP Peer item name" field is not found')
                         )]),
                 add_label=_('Add BGP peer'),
                 movable=False,
                 title=_('BGP peer specific configuration'),
             )),

        ],
    ),
    TextAscii(title=_('Huawei BGP peer')),
    match_type='dict',
)
